@@ -18,7 +18,7 @@ class IsPycharmRun:
         def wrapped_function(*args):
             if self.isPycharmRun():
                 print(func.__name__ + " was called")
-                return func(basedir=args[0], devices=self.deviceUrl, logdir=self.logDir)
+                return func(basedir=args[0], devices=self.deviceUrl)
             else:
                 return func(*args)
         return wrapped_function
